aboutsummaryrefslogtreecommitdiff
path: root/contrib/verifysfbinaries/verify.sh
diff options
context:
space:
mode:
authorWladimir J. van der Laan <laanwj@gmail.com>2014-06-29 08:45:54 +0200
committerWladimir J. van der Laan <laanwj@gmail.com>2014-06-29 08:49:26 +0200
commita11f648585ce29ae0be1a572ccbd7611f3dd2b1d (patch)
treeedf5eab57371172e4deb74cc934ac32a90a387b7 /contrib/verifysfbinaries/verify.sh
parent7b8fc9d8ad4791269fb8439126b5ceff39217f56 (diff)
parentffebc1be43751050c0b35d7140ba127783708d13 (diff)
downloadbitcoin-a11f648585ce29ae0be1a572ccbd7611f3dd2b1d.tar.xz
Merge pull request #4441
ffebc1b Update verify.sh script to point to bitcoin.org (Michael Ford)
Diffstat (limited to 'contrib/verifysfbinaries/verify.sh')
-rwxr-xr-xcontrib/verifysfbinaries/verify.sh8
1 files changed, 4 insertions, 4 deletions
diff --git a/contrib/verifysfbinaries/verify.sh b/contrib/verifysfbinaries/verify.sh
index e92295661c..3eb4693883 100755
--- a/contrib/verifysfbinaries/verify.sh
+++ b/contrib/verifysfbinaries/verify.sh
@@ -1,6 +1,6 @@
#!/bin/bash
### This script attempts to download the signature file SHA256SUMS.asc from SourceForge
### It first checks if the signature passes, and then downloads the files specified in
### the file, and checks if the hashes of these files match those that are specified
### in the signature file.
@@ -18,11 +18,11 @@ WORKINGDIR="/tmp/bitcoin"
TMPFILE="hashes.tmp"
#this URL is used if a version number is not specified as an argument to the script
-SIGNATUREFILE="http://downloads.sourceforge.net/project/bitcoin/Bitcoin/bitcoin-0.9.0rc1/SHA256SUMS.asc"
+SIGNATUREFILE="https://bitcoin.org/bin/0.9.2.1/SHA256SUMS.asc"
SIGNATUREFILENAME="SHA256SUMS.asc"
RCSUBDIR="test/"
-BASEDIR="http://downloads.sourceforge.net/project/bitcoin/Bitcoin/"
+BASEDIR="https://bitcoin.org/bin/"
VERSIONPREFIX="bitcoin-"
RCVERSIONSTRING="rc"
@@ -62,7 +62,7 @@ WGETOUT=$(wget -N "$BASEDIR$SIGNATUREFILENAME" 2>&1)
#and then see if wget completed successfully
if [ $? -ne 0 ]; then
echo "Error: couldn't fetch signature file. Have you specified the version number in the following format?"
- echo "[bitcoin-]<version>-[rc[0-9]] (example: bitcoin-0.7.1-rc1)"
+ echo "[bitcoin-]<version>-[rc[0-9]] (example: bitcoin-0.9.2-rc1)"
echo "wget output:"
echo "$WGETOUT"|sed 's/^/\t/g'
exit 2
@@ -1,6 +1,6 @@
#!/bin/bash
-### This script attempts to download the signature file SHA256SUMS.asc from SourceForge
+### This script attempts to download the signature file SHA256SUMS.asc from bitcoin.org
### It first checks if the signature passes, and then downloads the files specified in
### the file, and checks if the hashes of these files match those that are specified